@@ -2,9 +2,9 @@
 package Require::HookChain;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-07-23'; # DATE
+our $DATE = '2023-12-05'; # DATE
 our $DIST = 'Require-HookChain'; # DIST
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 #IFUNBUILT
 # use strict;
@@ -151,10 +151,13 @@ Require::HookChain - Chainable require hooks
 
 =head1 VERSION
 
-This document describes version 0.015 of Require::HookChain (from Perl distribution Require-HookChain), released on 2023-07-23.
+This document describes version 0.016 of Require::HookChain (from Perl distribution Require-HookChain), released on 2023-12-05.
 
 =head1 SYNOPSIS
 
+B<NOTE:> Please see L<Require::HookPlugin> instead which will supersede this
+project.
+
 Say you want to create a require hook to prepend some code to the module source
 code that is loaded. In your hook source, in
 F<Require/HookChain/munge/prepend.pm>:
@@ -374,6 +377,47 @@ instead of:
 You control the ordering by putting the hooks in C<@INC> in your preferred
 order. See L</"Hook ordering"> for more details.
 
+=head2 What are the differences between Require::HookChain and Require::HookPlugin?
+
+=begin BEGIN_BLOCK:rhc_vs_rhp
+
+
+
+
+=end BEGIN_BLOCK:rhc_vs_rhp
+
+Require::HookChain (RHC) and Require::HookPlugin (RHP) are both frameworks to
+add custom behavior to the module loading process. The following are the
+comparison between the two:
+
+RHC and RHP both work by installing its own handler (a coderef) at the beginning
+of C<@INC>. They then evaluate the rest of C<@INC> like Perl does, with some
+differences.
+
+Perl stops at the first C<@INC> element where it finds the source code, while
+RHC's handler evaluates all the entries of C<@INC> looking for hooks in the form
+of objects of the class under the C<Require::HookChain::> namespace.
+
+RHP's plugins, on the other hand, are not installed directly in C<@INC> but at
+another array (C<@Require::HookPlugin::Plugin_Instances>), so the only entry
+installed in C<@INC> is RHP's own handler.
+
+RHC evaluates hooks in C<@INC> in order, so you have to install the hooks in the
+right order to get the correct behavior. On the other hand, RHP evaluates
+plugins based on events, plugins' priority, and activation order. Plugins have a
+default priority value (though you can override it). In general you can activate
+plugins in whatever order and generally they will do the right thing. RHP is
+more flexible and powerful than RHC, but is slightly more complex.
+
+Writing hooks for RHC (or plugins for RHP) are roughly equally easy.
+
+=begin END_BLOCK:rhc_vs_rhp
+
+
+
+
+=end END_BLOCK:rhc_vs_rhp
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Require-HookChain>.
@@ -386,7 +430,12 @@ Source repository is at L<https://github.com/perlancar/perl-Require-HookChain>.
 
 L<RHC> for convenience of using on the command-line or one-liners.
 
-L<Require::Hook> is an older framework and is superseded by Require::HookChain.q
+L<Require::Hook> (RH) is an older framework and is superseded by
+Require::HookChain (RHC).
+
+L<Require::HookPlugin> (RHP) is a newer framework that aims to be more flexible
+and comes with sensible default of ordering, to avoid the trap of installing
+hooks at the wrong order. RHP might supersede RHC in the future.
 
 =head1 AUTHOR
 
