@@ -7,9 +7,9 @@ package Require::HookChain::munge::prepend;
 #END IFUNBUILT
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-07-23'; # DATE
+our $DATE = '2023-12-05'; # DATE
 our $DIST = 'Require-HookChain'; # DIST
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 sub new {
     my ($class, $preamble) = @_;
@@ -44,7 +44,7 @@ Require::HookChain::munge::prepend - Prepend a piece of code to module source
 
 =head1 VERSION
 
-This document describes version 0.015 of Require::HookChain::munge::prepend (from Perl distribution Require-HookChain), released on 2023-07-23.
+This document describes version 0.016 of Require::HookChain::munge::prepend (from Perl distribution Require-HookChain), released on 2023-12-05.
 
 =head1 SYNOPSIS
 
@@ -75,7 +75,10 @@ You might've installed the hook like this:
 
 in which case the hook is installed at the beginning of C<@INC> (after RHC's own
 hook). When a user C<require>'s a module, by the time the C<munge::prepend> hook
-runs, the source code is not yet available.
+runs, the source code is not yet available. You'll want to install the hook at
+the end of C<@INC> so other sources and hooks provide the source code first:
+
+ use Require::HookChain -end=>1, 'munge::prepend' => '...';
 
 =head1 HOMEPAGE
 
